@@ -11,6 +11,7 @@ NULL
 #' The first time will be long since it includes precompilation.
 #'
 #' @param ... Parameters are passed down to JuliaCall::julia_setup
+#' @param update if \code{TRUE} update the  TKTDsimulations.jl pacakge. Default is \code{FALSE}
 #'
 #' @examples
 #'
@@ -21,8 +22,11 @@ NULL
 #' }
 #'
 #' @export
-tktdjl2r_setup <- function (...){
+tktdjl2r_setup <- function (..., update=FALSE){
   julia <- JuliaCall::julia_setup(...)
   JuliaCall::julia_install_package_if_needed("TKTDsimulations")
+  if(update == TRUE){
+    JuliaCall::julia_update_package("TKTDsimulations")
+  }
   JuliaCall::julia_library("TKTDsimulations")
 }
